@@ -1,6 +1,6 @@
 permcoefs.plsRnp <- function(dataRepYtt,ind,nt,modele,maxcoefvalues,wwetoile,ifbootfail){
 dataRepYb=dataRepYtt[ind,1]
-Tb=dataRepYtt[ind,-1]
+Tb=dataRepYtt[,-1]
 tempCb=try(solve(t(Tb)%*%Tb)%*%t(Tb)%*%dataRepYb,silent=TRUE)
 tempcoefs <- rbind(Intercept=0,wwetoile%*%tempCb)
     Cond <- FALSE
